@@ -163,7 +163,7 @@ do{ my $x = [
          'additional_cflags' => '-I/opt/local/include/smpeg -I/opt/local/include -I/usr/include',
          'additional_libs' => '-L/usr/lib',
          'build_arch' => 'darwin-thread-multi-2level',
-         'build_cc' => '/usr/bin/clang',
+         'build_cc' => '/usr/bin/cc',
          'build_os' => 'darwin',
          'build_params' => {
                              'buildtype' => 'use_config_script',
@@ -176,7 +176,7 @@ do{ my $x = [
                        'ld_paths' => [],
                        'ld_shared_libs' => [
                                              '/usr/lib/libpthread.dylib',
-                                             '/usr/lib/libz.dylib',
+                                             '/opt/local/lib/libz.dylib',
                                              '/opt/local/lib/libjpeg.8.dylib',
                                              '/opt/local/lib/libtiff.5.dylib',
                                              '/opt/local/lib/libpng16.16.dylib',
@@ -190,10 +190,10 @@ do{ my $x = [
                                              '/opt/local/lib/libgmodule-2.0.dylib',
                                              '/opt/local/lib/libglib-2.0.0.dylib',
                                              '/opt/local/lib/libfontconfig.dylib',
-                                             '/usr/lib/libexpat.dylib'
+                                             '/opt/local/lib/libexpat.dylib'
                                            ],
                        'ld_shlib_map' => {
-                                           'expat' => '/usr/lib/libexpat.dylib',
+                                           'expat' => '/opt/local/lib/libexpat.dylib',
                                            'fontconfig' => '/opt/local/lib/libfontconfig.dylib',
                                            'freetype' => '/opt/local/lib/libfreetype.dylib',
                                            'glib' => '/opt/local/lib/libglib-2.0.0.dylib',
@@ -208,7 +208,7 @@ do{ my $x = [
                                            'tiff' => '/opt/local/lib/libtiff.5.dylib',
                                            'vorbis' => '/opt/local/lib/libvorbis.dylib',
                                            'vorbisfile' => '/opt/local/lib/libvorbisfile.3.dylib',
-                                           'z' => '/usr/lib/libz.dylib'
+                                           'z' => '/opt/local/lib/libz.dylib'
                                          }
                      },
          'script' => 'sdl-config'
